@@ -3,7 +3,7 @@ use parent 'HealthCheck::Diagnostic';
 
 # ABSTRACT: A health check for your code
 use version;
-our $VERSION = 'v1.9.0'; # VERSION
+our $VERSION = 'v1.9.1'; # VERSION
 
 use 5.010;
 use strict;
@@ -446,9 +446,9 @@ sub get_registered_tags {
         $self->_set_check_response_defaults($check);
         push @tags, @{ $check->{_respond}{tags} || [] };
     }
-    push @tags, @{$self->{tags} // ()};
+    push @tags, @{ $self->{tags} // [] };
 
-    return sort {$a cmp $b} uniq @tags;
+    return uniq sort @tags;
 }
 
 sub run {
@@ -633,7 +633,7 @@ HealthCheck - A health check for your code
 
 =head1 VERSION
 
-version v1.9.0
+version v1.9.1
 
 =head1 SYNOPSIS
 
